==> employment-common-core-1.0.2-sources.jar: com/ptteng/sca/employment/common/client/BankSCAClient.java <==
/**
 *
 */
package com.ptteng.sca.employment.common.client;

import java.util.List;
import java.util.Map;

import com.ptteng.employment.common.model.Bank;
import com.ptteng.employment.common.service.BankService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class BankSCAClient implements BankService {

    private BankService bankService;

    public BankService getBankService() {
        return bankService;
    }


    public void setBankService(BankService bankService) {
        this.bankService = bankService;
    }


    @Override
    public Long insert(Bank bank) throws ServiceException, ServiceDaoException {

        return bankService.insert(bank);


    }


    @Override
    public List<Bank> insertList(List<Bank> bankList) throws ServiceException, ServiceDaoException {

        return bankService.insertList(bankList);


    }


    @Override
    public boolean delete(Long id) throws ServiceException, ServiceDaoException {

        return bankService.delete(id);


    }


    @Override
    public boolean update(Bank bank) throws ServiceException, ServiceDaoException {

        return bankService.update(bank);


    }


    @Override
    public boolean updateList(List<Bank> bankList) throws ServiceException, ServiceDaoException {

        return bankService.updateList(bankList);


    }


    @Override
    public Bank getObjectById(Long id) throws ServiceException, ServiceDaoException {

        return bankService.getObjectById(id);


    }


    @Override
    public List<Bank> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException {

        return bankService.getObjectsByIds(ids);


    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long> getBankIdsByUserId(Long userId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {

        return bankService.getBankIdsByUserId(userId, start, limit);


    }

    @Override
    public List<Long> getBankIdsByUserIdAndCustomerId(Long userId, Long customerId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return bankService.getBankIdsByUserIdAndCustomerId(userId,customerId, start, limit);
    }

    @Override
    public Long getBankIdsByUserIdAndCustomerIdAndStatus(Long userId, Long customerId, Integer status) throws ServiceException, ServiceDaoException {
        return bankService.getBankIdsByUserIdAndCustomerIdAndStatus(userId, customerId, status);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Integer countBankIdsByUserId(Long userId) throws ServiceException, ServiceDaoException {

        return bankService.countBankIdsByUserId(userId);


    }


    @Override
    public List<Long> getBankIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.getBankIds(start, limit);
    }

    @Override
    public Integer countBankIds() throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.countBankIds();
    }


    @Override
    public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.getIdsByDynamicCondition(clz, conditions, start, limit);
    }


    @Override
    public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.fakeDelete(clz, id);
    }


    @Override
    public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
        bankService.deleteList(clz, ids);

    }

    @Override
    public Object getObjectByDynamicCondition(Class clz,
                                              Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {

        return this.bankService.getObjectByDynamicCondition(clz, conditions, start, limit);
    }

    @Override
    public Object getMapListByDynamicCondition(Class clz,
                                               Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {

        return this.bankService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}

==> employment-common-core-1.1.0-sources.jar: com/ptteng/sca/employment/common/client/BankSCAClient.java <==
/**
 *
 */
package com.ptteng.sca.employment.common.client;

import java.util.List;
import java.util.Map;

import com.ptteng.employment.common.model.Bank;
import com.ptteng.employment.common.service.BankService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class BankSCAClient implements BankService {

    private BankService bankService;

    public BankService getBankService() {
        return bankService;
    }


    public void setBankService(BankService bankService) {
        this.bankService = bankService;
    }


    @Override
    public Long insert(Bank bank) throws ServiceException, ServiceDaoException {

        return bankService.insert(bank);


    }


    @Override
    public List<Bank> insertList(List<Bank> bankList) throws ServiceException, ServiceDaoException {

        return bankService.insertList(bankList);


    }


    @Override
    public boolean delete(Long id) throws ServiceException, ServiceDaoException {

        return bankService.delete(id);


    }


    @Override
    public boolean update(Bank bank) throws ServiceException, ServiceDaoException {

        return bankService.update(bank);


    }


    @Override
    public boolean updateList(List<Bank> bankList) throws ServiceException, ServiceDaoException {

        return bankService.updateList(bankList);


    }


    @Override
    public Bank getObjectById(Long id) throws ServiceException, ServiceDaoException {

        return bankService.getObjectById(id);


    }


    @Override
    public List<Bank> getObjectsByIds(List<Long> ids) throws ServiceException, ServiceDaoException {

        return bankService.getObjectsByIds(ids);


    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public List<Long> getBankIdsByUserId(Long userId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {

        return bankService.getBankIdsByUserId(userId, start, limit);


    }

    @Override
    public List<Long> getBankIdsByUserIdAndCustomerId(Long userId, Long customerId, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return bankService.getBankIdsByUserIdAndCustomerId(userId,customerId, start, limit);
    }

    @Override
    public Long getBankIdsByUserIdAndCustomerIdAndStatus(Long userId, Long customerId, Integer status) throws ServiceException, ServiceDaoException {
        return bankService.getBankIdsByUserIdAndCustomerIdAndStatus(userId, customerId, status);
    }

    @Override
    public Long getLastBankByUserIdAndStatus(Long userId, Integer status) throws ServiceException, ServiceDaoException {
        return bankService.getLastBankByUserIdAndStatus(userId, status);
    }


    /**
     *
     * @param
     * @return
     * @throws ServiceException
     * @throws ServiceDaoException
     */
    @Override
    public Integer countBankIdsByUserId(Long userId) throws ServiceException, ServiceDaoException {

        return bankService.countBankIdsByUserId(userId);


    }


    @Override
    public List<Long> getBankIds(Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.getBankIds(start, limit);
    }

    @Override
    public Integer countBankIds() throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.countBankIds();
    }


    @Override
    public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.getIdsByDynamicCondition(clz, conditions, start, limit);
    }


    @Override
    public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
        // TODO Auto-generated method stub
        return bankService.fakeDelete(clz, id);
    }


    @Override
    public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
        bankService.deleteList(clz, ids);

    }

    @Override
    public Object getObjectByDynamicCondition(Class clz,
                                              Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {

        return this.bankService.getObjectByDynamicCondition(clz, conditions, start, limit);
    }

    @Override
    public Object getMapListByDynamicCondition(Class clz,
                                               Map<String, Object> conditions, Integer start, Integer limit)
            throws ServiceException, ServiceDaoException {

        return this.bankService.getMapListByDynamicCondition(clz, conditions, start, limit);
    }


}
